@@ -6,8 +6,10 @@
 
 #include <iterator>
 
+#include "wchar_t_short.h"
 #include <nsCOMPtr.h>
 #include <nsIDOMNode.h>
+#include "wchar_t_default.h"
 
 class child_iterator
     : public std::iterator<std::input_iterator_tag, nsCOMPtr<nsIDOMNode>,
