@@ -1,6 +1,7 @@
 // Copyright 2005-8 Ben Hutchings <ben@decadent.org.uk>.
 // See the file "COPYING" for licence details.
 
+#include <cassert>
 #include <cerrno>
 #include <cstring>
 #include <fstream>
@@ -251,7 +252,7 @@ void dvd_generator::generate_menu_vob(unsigned index,
 	    " -loop_input -i " << background_name <<
 	    " -t " << menu_duration_seconds(frame_params_) <<
 	    " -target " << frame_params_.common_name <<  "-dvd"
-	    " -vcodec mpeg2video -aspect 4:3 -an -y /dev/stdout";
+	    " -aspect 4:3 -an -y /dev/stdout";
     }
     else
     {
