@@ -6,6 +6,7 @@
 
 #include <langinfo.h>
 
+#include "wchar_t_short.h"
 #include <nsCOMPtr.h>
 #include <nsICharsetConverterManager.h>
 #include <nsIComponentManager.h>
@@ -13,6 +14,7 @@
 #include <nsIComponentRegistrar.h>
 #include <nsServiceManagerUtils.h>
 #include <nsIUnicodeEncoder.h>
+#include "wchar_t_default.h"
 
 #include "null_prompt_service.hpp"
 #include "videolink.hpp"
