@@ -3,12 +3,14 @@
 
 #include "style_sheets.hpp"
 
+#include "wchar_t_short.h"
 #include <nsCOMPtr.h>
 #include <nsContentCID.h>
 #include <nsIStyleSheetService.h>
 #include <nsServiceManagerUtils.h>
 #include <nsIURI.h>
 #include <nsNetUtil.h>
+#include "wchar_t_default.h"
 
 #include "xpcom_support.hpp"
 
