@@ -6,7 +6,9 @@
 
 #include <stdexcept>
 
+#include "wchar_t_short.h"
 #include <nsError.h>
+#include "wchar_t_default.h"
 
 namespace xpcom_support
 {
